This directory contains information about regiments taken directry from SFS
archives.

``regShort.properties`` was renamed to ``regShort_en.properties``,
``regInfo.properties`` was renamed to ``regInfo_en.properties``. These names
**must** be retained!

**Do not** edit or resave the contents of files in this directory manually!
Take them from SFS archives instead.
